<?php

namespace Drupal\dblog_filter\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Component\Render\FormattableMarkup;

/**
 * The DBLogFilterSettingsForm class.
 */
class DBLogFilterSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dblog_filter_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['dblog_filter.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('dblog_filter.settings');
    $log_levels = RfcLogLevel::getLevels();
    foreach ($log_levels as $log_level) {
      $log_level_value = $log_level->getUntranslatedString();
      $severity_levels[strtolower($log_level_value)] = $log_level_value;
    }
    $form['severity_levels'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select Severity Levels'),
      '#description' => $this->t('Only the selected severity logs will be recorded'),
      '#options' => $severity_levels ?? [],
      '#default_value' => $config->get('severity_levels') ?? [],
    ];
    $form['log_values'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Enter DB Log type and Severity Levels.'),
      '#default_value' => $config->get('log_values'),
    ];

    $form['method'] = [
      '#type' => 'radios',
      '#title' => $this->t("Method"),
      '#default_value' => $config->get('method') ?: 'include',
      '#options' => [
        'include' => $this->t('Only save selected'),
        'exclude' => $this->t('Save all but selected'),
      ],
    ];

    $log_values_description = new FormattableMarkup(
      '<i>Severity Levels: emergency, alert, critical, error, warning, notice, info, debug</i>
             <br/>
             <i>Log Types: php, cron, mail, mymodule, etc.</i>
             <p>
             @description
             <br/>
             <strong>
               @example_1
               <br/>
               @example_2
             </strong>
             </p>',
      [
        '@description' => 'Enter one value per line, in the format log_type|level1,level2,level3.. to restrict the log messages stored',
        '@example_1' => 'Example: php|error,notice,warning',
        '@example_2' => 'mymodule|error,notice',
      ]
    );

    $form['description'] = [
      '#markup' => $this->t('@log_values_description', ['@log_values_description' => $log_values_description]),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save configurations.
    $config = $this->config('dblog_filter.settings')
      ->set('log_values', $form_state->getValue('log_values'))
      ->set('severity_levels', $form_state->getValue('severity_levels'))
      ->set('method', $form_state->getValue('method'));
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
